@@ -28,6 +28,8 @@ remotes_list = param['remotes']
 remote = {'bucket': 'fire-emergency-nz', 'connection_config': 'https://b2.tethys-ts.xyz'}
 remote = {'bucket': 'es-hilltop', 'connection_config': 'https://b2.tethys-ts.xyz'}
 remote = {'bucket': 'niwa-cliflo', 'connection_config': 'https://b2.tethys-ts.xyz'}
+remote = {'bucket': 'ecan-env-monitoring', 'connection_config': 'https://b2.tethys-ts.xyz'}
+remote = {'bucket': 'nz-forecasts', 'connection_config': 'https://b2.tethys-ts.xyz'}
 # remote = {'bucket': 'nasa-data', 'connection_config': 'https://b2.tethys-ts.xyz'}
 remote = remotes_list[-1]
 # remote['connection_config'] = 'https://b2.tethys-ts.xyz'
@@ -56,6 +58,15 @@ station_id = 'dfb66ed0f4835161a7001d45'
 
 dataset_id = 'fb77f37b16edae3534e73ddd'
 station_id = 'fd60b5bafe19d6b243dda43d'
+
+dataset_id = 'e37f1451fcf8f9e64b66be8d'
+
+dataset_id = '9c7e107f99180e45eafdf5af'
+station_id = 'c6df8b47b2efce3daedef48e'
+station_id = 'a3f2d35fd6df8247cea32d03'
+
+dataset_id = '9bf36a9e6b6a2a111bf6634b'
+station_id = '4db28a9db0cb036507490887'
 #
 #
 self = Tethys([remote])
@@ -93,7 +104,7 @@ stn = [s for s in stn_list1 if s['station_id'] == station_id]
 stn = [s for s in stn_list1 if 'Waiau River' in s['ref']]
 
 
-
+gwl_ds1 = [d for d in self.datasets if d['parameter'] == 'groundwater_depth']
 
 
 
